==> activity-center-biz-1.2.6-zlh-20161018.120904-3-sources.jar: cn/com/duiba/activity/center/biz/constant/MemcachedSpace.java <==
package cn.com.duiba.activity.center.biz.constant;

public class MemcachedSpace {
	/**
	 * 用户的最后一次兑换时间记录
	 * 业务使用场景：同一个用户兑换的时间间隔不能小于3秒
	 */
	public static final int MS_LAST_EXCHANGE=100;
	/**
	 * IP兑换限制
	 * 每个ip一天只能兑换10次
	 * key=101-ip
	 * value=8
	 * 隔天凌晨失效
	 */
	public static final int MS_IP_EXCHANGE_LIMIT=101;
	/**
	 * 商城用户表单token
	 * 一个月过期，或者使用一次后删除
	 */
	public static final int MS_FORM_CONSUMER_TOKEN=102;
	/**
	 * 反作弊用户兑换行为监控
	 * 当超出限制后，将相关信息记入可疑黑名单
	 */
	public static final int MS_ANTICHEAT_EXCHANGE=103;
	/**
	 * 反作弊IP白名单
	 * 格式
	 * ip;ip;ip
	 */
	public static final int MS_ANTICHEAT_WHITE_LIST=104;
	
	/**
	 * Banner,Icon,Item 上下架通知
	 */
	public static final int MS_STATUS_MODIFY_NOTIFY=105;
	/**
	 * App扣积分接口失败报警
	 * 记录当天某个App扣积分失败的次数
	 * key: 106-appId
	 * value: 10
	 */
	public static final int MS_CONSUME_CREDITS_FAIL_ALARM=106;
	/**
	 * 一个App连续的用户id进行优惠劵兑换，记录信息，用来判断是否可疑用户
	 * key: appid-itemId
	 * value: List<Long> partnerUserId列表
	 * 数据量大小： appId*itemId  应该不超过1W
	 */
	public static final int MS_CONSUMER_SUSPICION=107;
	
	/**
	 * app开发者后台表单token
	 * 一个月过期，或者使用一次后删除
	 */
	public static final int MS_FORM_APP_TOKEN = 108;
	
	/**
	 * 管理员后台表单token
	 * 一个月过期，或者使用一次后删除
	 */
	public static final int MS_FORM_ADMIN_TOKEN = 109;
	
	/**
	 * 抽奖奖项，缓存空间前缀
	 */
	public static final int MS_FROM_PRIZE = 110;
	
	/**
	 * 防作弊策略：AnticheatSameCreditsStrategy
	 * key:  appId-itemId-credits
	 */
	public static final int MS_ANTICHEAT_CREDITS=111;
	
	/**
	 * 首页跑马灯30条
	 */
	public static final int MS_CHOME_MARQUEE = 112;
	/**
	 * 开发者发送激活邮件间隔标记，只要此标记存在就不能重发，间隔1分钟
	 */
	public static final int MS_SEND_VERIFY_EMAIL = 113;
	/**
	 * 短信验证码标记，用于短信验证码的校验
	 */
	public static final int MS_PHONE_CODE = 114;
	/**
	 * 秒杀验证码
	 */
	public static final int MS_CAPTCHCA = 116;
	/**
	 * 首页APP商品缓存
	 */
	public static final int MS_HOME_ITEM = 117;
	/**
	 * 首页APPbanner缓存
	 */
	public static final int MS_HOME_BANNER = 118;
	/**
	 * 扣积分成功缓存key
	 */
	public static final int MS_CONSUME_CREDITS_SUCCESS = 119;

	/**
	 * 防作弊校验
	 */
	public static final int MS_ANTICHEATCHECK = 120;
	
	/**
	 * 预分配库存
	 */
	public static final int MS_PRE_STOCK_QUANTITY = 121;
	/**
	 * 微信获取ACCESS_TOKEN
	 */
	public static final int MS_WEIXIN = 122;
	/**
	 * 运费模板缓存key
	 */
	public static final int MS_EXPRESS_TEMPLATE = 123;
	/**
	 * APP QPS并发限流
	 */
	public static final int MS_APP_QPS_LIMIT=130;

	/**
	 * 秒杀队列长度的缓存
	 */
	public static final int MS_SECONDKILL_QUEUE=132;
	
	/**
	 * 防重复锁的缓存
	 */
	public static final int MS_FROM_LOCK=133;
	
	/**
	 * 游戏前多少明列表缓存
	 */
	public static final String MS_GAME_SCORE_DESC = "MS_GAME_SCORE_DESC";
	/**
	 * 游戏活动规则缓存
	 */
	public static final String MS_GAME_RULS = "MS_GAME_RULS";
	/**
	 * 游戏奖项展示缓存
	 */
	public static final String MS_GAME_OPTION = "MS_GAME_OPTIONS";
	
	/**
	 * 游戏活动规则缓存
	 */
	public static final String MS_NGAME_RULS = "MS_NGAME_RULS";
	
	/**
	 * 游戏奖项展示缓存
	 */
	public static final String MS_NGAME_OPTION = "MS_NGAME_OPTIONS";
	
	/**
	 * 游戏前多少明列表缓存
	 */
	public static final String MS_NGAME_SCORE_DESC = "MS_NGAME_SCORE_DESC";
	
	
	public static final String MS_APPCACHE="MS_APPCACHE";
	
	/**
	 * QQ浏览器风控缓存
	 */
	public static final String MS_QQ_BROWERS_CACHE = "MS_QQ_BROWERS_CACHE";
	
	/**
	 * 福袋请求接口请求返回缓存
	 */
	public static final String MS_LUCK_BAG_CACHE = "MS_LUCK_BAG_CACHE";
	
    /**
     * 黑名单的缓存key
     */
    public static final String KEY_BLACK = "chaos.black_";
    
    /**
     * 子页面定向白名单缓存
     */
    public static final String MS_CATEGORY_SPECIFY_CACHE = "MS_CATEGORY_SPECIFY_CACHE";

	public static final String MS_SECKILL_EXCHANGE_LOG = "seckill-1-";

	public static final String MS_SECKILL_STOCK = "seckill-2-";

	/**
	 * 秒杀系统app缓存
	 */
	public static final String MS_APP_CACHE = "seckill-4-";
}

==> activity-center-biz-1.2.9.8.zlh-20161114.112404-1-sources.jar: cn/com/duiba/activity/center/biz/constant/MemcachedSpace.java <==
package cn.com.duiba.activity.center.biz.constant;

public class MemcachedSpace {
	/**
	 * 用户的最后一次兑换时间记录
	 * 业务使用场景：同一个用户兑换的时间间隔不能小于3秒
	 */
	public static final int MS_LAST_EXCHANGE=100;
	/**
	 * IP兑换限制
	 * 每个ip一天只能兑换10次
	 * key=101-ip
	 * value=8
	 * 隔天凌晨失效
	 */
	public static final int MS_IP_EXCHANGE_LIMIT=101;
	/**
	 * 商城用户表单token
	 * 一个月过期，或者使用一次后删除
	 */
	public static final int MS_FORM_CONSUMER_TOKEN=102;
	/**
	 * 反作弊用户兑换行为监控
	 * 当超出限制后，将相关信息记入可疑黑名单
	 */
	public static final int MS_ANTICHEAT_EXCHANGE=103;
	/**
	 * 反作弊IP白名单
	 * 格式
	 * ip;ip;ip
	 */
	public static final int MS_ANTICHEAT_WHITE_LIST=104;
	
	/**
	 * Banner,Icon,Item 上下架通知
	 */
	public static final int MS_STATUS_MODIFY_NOTIFY=105;
	/**
	 * App扣积分接口失败报警
	 * 记录当天某个App扣积分失败的次数
	 * key: 106-appId
	 * value: 10
	 */
	public static final int MS_CONSUME_CREDITS_FAIL_ALARM=106;
	/**
	 * 一个App连续的用户id进行优惠劵兑换，记录信息，用来判断是否可疑用户
	 * key: appid-itemId
	 * value: List<Long> partnerUserId列表
	 * 数据量大小： appId*itemId  应该不超过1W
	 */
	public static final int MS_CONSUMER_SUSPICION=107;
	
	/**
	 * app开发者后台表单token
	 * 一个月过期，或者使用一次后删除
	 */
	public static final int MS_FORM_APP_TOKEN = 108;
	
	/**
	 * 管理员后台表单token
	 * 一个月过期，或者使用一次后删除
	 */
	public static final int MS_FORM_ADMIN_TOKEN = 109;
	
	/**
	 * 抽奖奖项，缓存空间前缀
	 */
	public static final int MS_FROM_PRIZE = 110;
	
	/**
	 * 防作弊策略：AnticheatSameCreditsStrategy
	 * key:  appId-itemId-credits
	 */
	public static final int MS_ANTICHEAT_CREDITS=111;
	
	/**
	 * 首页跑马灯30条
	 */
	public static final int MS_CHOME_MARQUEE = 112;
	/**
	 * 开发者发送激活邮件间隔标记，只要此标记存在就不能重发，间隔1分钟
	 */
	public static final int MS_SEND_VERIFY_EMAIL = 113;
	/**
	 * 短信验证码标记，用于短信验证码的校验
	 */
	public static final int MS_PHONE_CODE = 114;
	/**
	 * 秒杀验证码
	 */
	public static final int MS_CAPTCHCA = 116;
	/**
	 * 首页APP商品缓存
	 */
	public static final int MS_HOME_ITEM = 117;
	/**
	 * 首页APPbanner缓存
	 */
	public static final int MS_HOME_BANNER = 118;
	/**
	 * 扣积分成功缓存key
	 */
	public static final int MS_CONSUME_CREDITS_SUCCESS = 119;

	/**
	 * 防作弊校验
	 */
	public static final int MS_ANTICHEATCHECK = 120;
	
	/**
	 * 预分配库存
	 */
	public static final int MS_PRE_STOCK_QUANTITY = 121;
	/**
	 * 微信获取ACCESS_TOKEN
	 */
	public static final int MS_WEIXIN = 122;
	/**
	 * 运费模板缓存key
	 */
	public static final int MS_EXPRESS_TEMPLATE = 123;
	/**
	 * APP QPS并发限流
	 */
	public static final int MS_APP_QPS_LIMIT=130;

	/**
	 * 秒杀队列长度的缓存
	 */
	public static final int MS_SECONDKILL_QUEUE=132;
	
	/**
	 * 防重复锁的缓存
	 */
	public static final int MS_FROM_LOCK=133;
	
	/**
	 * 游戏前多少明列表缓存
	 */
	public static final String MS_GAME_SCORE_DESC = "MS_GAME_SCORE_DESC";
	/**
	 * 游戏活动规则缓存
	 */
	public static final String MS_GAME_RULS = "MS_GAME_RULS";
	/**
	 * 游戏奖项展示缓存
	 */
	public static final String MS_GAME_OPTION = "MS_GAME_OPTIONS";
	
	/**
	 * 游戏活动规则缓存
	 */
	public static final String MS_NGAME_RULS = "MS_NGAME_RULS";
	
	/**
	 * 游戏奖项展示缓存
	 */
	public static final String MS_NGAME_OPTION = "MS_NGAME_OPTIONS";
	
	/**
	 * 游戏前多少明列表缓存
	 */
	public static final String MS_NGAME_SCORE_DESC = "MS_NGAME_SCORE_DESC";
	
	
	public static final String MS_APPCACHE="MS_APPCACHE";
	
	/**
	 * QQ浏览器风控缓存
	 */
	public static final String MS_QQ_BROWERS_CACHE = "MS_QQ_BROWERS_CACHE";
	
	/**
	 * 福袋请求接口请求返回缓存
	 */
	public static final String MS_LUCK_BAG_CACHE = "MS_LUCK_BAG_CACHE";
	
    /**
     * 黑名单的缓存key
     */
    public static final String KEY_BLACK = "chaos.black_";
    
    /**
     * 子页面定向白名单缓存
     */
    public static final String MS_CATEGORY_SPECIFY_CACHE = "MS_CATEGORY_SPECIFY_CACHE";

	public static final String MS_SECKILL_EXCHANGE_LOG = "seckill-1-";

	public static final String MS_SECKILL_STOCK = "seckill-2-";

	/**
	 * 秒杀系统app缓存
	 */
	public static final String MS_APP_CACHE = "seckill-4-";
	/**
	 * 物料信息缓存
	 */
	public static final String MS_ADMATERIAL_CACHE = "adMaterial-";
	
	/**
	 * 活动上架
	 */
	public static final String MA_ACTIVITY_ADD = "activity-add-";
	
	/**
	 * 广告活动查询 缓存
	 */
	public static final String MS_ADACTIVITY_QUERY = "advert-query-";
	/**
	 * 广告活动上架 缓存
	 */
	public static final String MS_ADACTIVITY_ADD = "advert-add-";
}
